boofun.analysis.global\_hypercontractivity
==========================================

.. automodule:: boofun.analysis.global_hypercontractivity


   .. rubric:: Functions

   .. autosummary::

      find_critical_p
      generalized_influence
      hypercontractivity_bound
      is_alpha_global
      lambda_p
      noise_stability_p_biased
      p_biased_character
      p_biased_expectation
      p_biased_influence
      p_biased_total_influence
      sigma
      threshold_curve

   .. rubric:: Classes

   .. autosummary::

      GlobalHypercontractivityAnalyzer
